==> codebuild-1.60.0-sources.jar: software/amazon/awscdk/services/codebuild/GitHubSourceCredentialsProps.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * Creation properties for {@link GitHubSourceCredentials}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:30.912Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.GitHubSourceCredentialsProps")
@software.amazon.jsii.Jsii.Proxy(GitHubSourceCredentialsProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface GitHubSourceCredentialsProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The personal access token to use when contacting the GitHub API.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.SecretValue getAccessToken();

    /**
     * @return a {@link Builder} of {@link GitHubSourceCredentialsProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GitHubSourceCredentialsProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<GitHubSourceCredentialsProps> {
        private software.amazon.awscdk.core.SecretValue accessToken;

        /**
         * Sets the value of {@link GitHubSourceCredentialsProps#getAccessToken}
         * @param accessToken The personal access token to use when contacting the GitHub API. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder accessToken(software.amazon.awscdk.core.SecretValue accessToken) {
            this.accessToken = accessToken;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GitHubSourceCredentialsProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public GitHubSourceCredentialsProps build() {
            return new Jsii$Proxy(accessToken);
        }
    }

    /**
     * An implementation for {@link GitHubSourceCredentialsProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GitHubSourceCredentialsProps {
        private final software.amazon.awscdk.core.SecretValue accessToken;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.accessToken = this.jsiiGet("accessToken", software.amazon.awscdk.core.SecretValue.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.core.SecretValue accessToken) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.accessToken = java.util.Objects.requireNonNull(accessToken, "accessToken is required");
        }

        @Override
        public software.amazon.awscdk.core.SecretValue getAccessToken() {
            return this.accessToken;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("accessToken", om.valueToTree(this.getAccessToken()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-codebuild.GitHubSourceCredentialsProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GitHubSourceCredentialsProps.Jsii$Proxy that = (GitHubSourceCredentialsProps.Jsii$Proxy) o;

            return this.accessToken.equals(that.accessToken);
        }

        @Override
        public int hashCode() {
            int result = this.accessToken.hashCode();
            return result;
        }
    }
}

==> codebuild-1.93.0-sources.jar: software/amazon/awscdk/services/codebuild/GitHubSourceCredentialsProps.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * Creation properties for {@link GitHubSourceCredentials}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:48.395Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.GitHubSourceCredentialsProps")
@software.amazon.jsii.Jsii.Proxy(GitHubSourceCredentialsProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface GitHubSourceCredentialsProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The personal access token to use when contacting the GitHub API.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.SecretValue getAccessToken();

    /**
     * @return a {@link Builder} of {@link GitHubSourceCredentialsProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GitHubSourceCredentialsProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<GitHubSourceCredentialsProps> {
        private software.amazon.awscdk.core.SecretValue accessToken;

        /**
         * Sets the value of {@link GitHubSourceCredentialsProps#getAccessToken}
         * @param accessToken The personal access token to use when contacting the GitHub API. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder accessToken(software.amazon.awscdk.core.SecretValue accessToken) {
            this.accessToken = accessToken;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GitHubSourceCredentialsProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public GitHubSourceCredentialsProps build() {
            return new Jsii$Proxy(accessToken);
        }
    }

    /**
     * An implementation for {@link GitHubSourceCredentialsProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GitHubSourceCredentialsProps {
        private final software.amazon.awscdk.core.SecretValue accessToken;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.accessToken = software.amazon.jsii.Kernel.get(this, "accessToken", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.SecretValue.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.core.SecretValue accessToken) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.accessToken = java.util.Objects.requireNonNull(accessToken, "accessToken is required");
        }

        @Override
        public final software.amazon.awscdk.core.SecretValue getAccessToken() {
            return this.accessToken;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("accessToken", om.valueToTree(this.getAccessToken()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-codebuild.GitHubSourceCredentialsProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GitHubSourceCredentialsProps.Jsii$Proxy that = (GitHubSourceCredentialsProps.Jsii$Proxy) o;

            return this.accessToken.equals(that.accessToken);
        }

        @Override
        public final int hashCode() {
            int result = this.accessToken.hashCode();
            return result;
        }
    }
}
